Commands
========


Global options
--------------

.. program-output:: passacre --help


``passacre init``
-----------------

.. program-output:: passacre init --help

Create a basic sqlite config.


``passacre generate``
---------------------

.. program-output:: passacre generate --help

Generate a password.


``passacre entropy``
--------------------

.. program-output:: passacre entropy --help

Show entropy for sites or schemata.


``passacre config``
---------------------

.. program-output:: passacre config --help

Set configuration globally or for a site.


``passacre info``
---------------------

.. program-output:: passacre info --help

Get information about the currently usable :ref:`features <features>`.
This will list all of the features,
whether the feature is usable,
and what modules need to be installed to make the feature usable.


``passacre schema``
---------------------

.. program-output:: passacre schema --help

Operate on schemata.


``passacre site``
---------------------

.. program-output:: passacre site --help

Operate on sites.
